require 'yaml'

module SSH
  module Ident

    # ssh ident config
    class Config
      def self.defaults
        {
            'FILE_USER_CONFIG' => "#{ENV['HOME']}/.ssh-ident",
            'DIR_IDENTITIES' => "#{ENV['HOME']}/.ssh/identities",
            'DIR_AGENTS' => "#{ENV['HOME']}/.ssh/agents",
            'DEFAULT_IDENTITY' => "#{ENV['USER']}",
            'SSH_ADD_OPTIONS' => '-t 7200'
        }
      end

      def initialize
        @values = load
      end

      def load
        if respond_to?(:load_custom)
          return load_custom
        end
        path = get('FILE_USER_CONFIG')
        return {} unless File.exist?(path)
        YAML.load(File.read(path))
      end

      def get(param)
        result = ENV[param]
        result ||= @values[param] if @values
        result ||= Config.defaults[param]
        fail "failed to find parameter #{param}" if result.nil?
        return File.expand_path(result) if result.is_a?(String) && result.include?('~')
        result
      end

      def set(param, value)
        @values[param] = value
      end
    end
  end
end
